@@ -44,7 +44,7 @@ class indicator:
     ###################
     # Clean
     ###################
-    def clean(s: AnyStr, esc: Optional[bytes]):
+    def clean(s: AnyStr, esc: Optional[bytes]=None):
         """
         Cleans off string off all ANSI ESC codes. If the detection does not pick up the ESC code you may supply one your self.
 
